@@ -28,7 +28,7 @@ int main(int argc, char **argv)
 	return(1);
   }
   if (argc < 2) {
-	printf("Is %s\n", ((st.st_mode & 022) == 022) ? "y" : "n");
+	printf("is %s\n", ((st.st_mode & 022) == 022) ? "y" : "n");
 	return(0);
   }
   if (argc > 2 || (argv[1][0] != 'y' && argv[1][0] != 'n')) {
